@@ -175,7 +175,7 @@ class Graph(object):
         """
         Restores all hidden edges.
         """
-        for edge in self.hidden_edges.keys():
+        for edge in list(self.hidden_edges.keys()):
             try:
                 self.restore_edge(edge)
             except GraphError:
@@ -185,7 +185,7 @@ class Graph(object):
         """
         Restores all hidden nodes.
         """
-        for node in self.hidden_nodes.keys():
+        for node in list(self.hidden_nodes.keys()):
             self.restore_node(node)
 
     def __contains__(self, node):
@@ -237,13 +237,13 @@ class Graph(object):
         """
         Return a list of the node ids for all visible nodes in the graph.
         """
-        return self.nodes.keys()
+        return list(self.nodes.keys())
 
     def edge_list(self):
         """
         Returns an iterator for all visible nodes in the graph.
         """
-        return self.edges.keys()
+        return list(self.edges.keys())
 
     def number_of_hidden_edges(self):
         """
@@ -261,13 +261,13 @@ class Graph(object):
         """
         Returns the list with the hidden nodes
         """
-        return self.hidden_nodes.keys()
+        return list(self.hidden_nodes.keys())
 
     def hidden_edge_list(self):
         """
         Returns a list with the hidden edges
         """
-        return self.hidden_edges.keys()
+        return list(self.hidden_edges.keys())
 
     def describe_node(self, node):
         """
@@ -311,16 +311,14 @@ class Graph(object):
         """
         List of nodes connected by outgoing edges
         """
-        l = map(self.tail, self.out_edges(node))
-        #l.sort()
+        l = [self.tail(n) for n in self.out_edges(node)]
         return l
 
     def inc_nbrs(self, node):
         """
         List of nodes connected by incoming edges
         """
-        l = map(self.head, self.inc_edges(node))
-        #l.sort()
+        l = [self.head(n) for n in self.inc_edges(node)]
         return l
 
     def all_nbrs(self, node):
@@ -660,7 +658,7 @@ class Graph(object):
 
         Typical usage::
 
-            >>> print graph.get_hops(1, 8)
+            >>> print (graph.get_hops(1, 8))
             >>> [(1, 0), (2, 1), (3, 1), (4, 2), (5, 3), (7, 4), (8, 5)]
             # node 1 is at 0 hops
             # node 2 is at 1 hop
